summaryrefslogtreecommitdiffstats
path: root/src/modules/bluetooth/bluetooth-util.h
diff options
context:
space:
mode:
authorJoão Paulo Rechi Vita <jprvita@gmail.com>2009-07-24 21:44:36 -0300
committerJoão Paulo Rechi Vita <jprvita@gmail.com>2009-08-23 22:46:56 -0300
commit2772521698caa4ffe7c0c2de174e9d901d7752fd (patch)
tree817154b06b16a5c343602f3bbf2060e756adf36f /src/modules/bluetooth/bluetooth-util.h
parent65c3e6576c635c06103fe44a4987b36de81db7a9 (diff)
bluetooth: add discover of bluetooth sources
Diffstat (limited to 'src/modules/bluetooth/bluetooth-util.h')
-rw-r--r--src/modules/bluetooth/bluetooth-util.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/modules/bluetooth/bluetooth-util.h b/src/modules/bluetooth/bluetooth-util.h
index f15f2170..e2a0c3d5 100644
--- a/src/modules/bluetooth/bluetooth-util.h
+++ b/src/modules/bluetooth/bluetooth-util.h
@@ -4,7 +4,7 @@
/***
This file is part of PulseAudio.
- Copyright 2008 Joao Paulo Rechi Vita
+ Copyright 2008-2009 Joao Paulo Rechi Vita
PulseAudio is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as
@@ -53,7 +53,7 @@ struct pa_bluetooth_uuid {
PA_LLIST_FIELDS(pa_bluetooth_uuid);
};
/* This enum is shared among Audio, Headset, and AudioSink, although not all values are acceptable in all profiles */
typedef enum pa_bt_audio_state {
PA_BT_AUDIO_STATE_INVALID = -1,
PA_BT_AUDIO_STATE_DISCONNECTED,
@@ -84,6 +84,9 @@ struct pa_bluetooth_device {
/* AudioSink state */
pa_bt_audio_state_t audio_sink_state;
+ /* AudioSource state */
+ pa_bt_audio_state_t audio_source_state;
+
/* Headset state */
pa_bt_audio_state_t headset_state;
};
@@ -53,7 +53,7 @@ struct pa_bluetooth_uuid {
PA_LLIST_FIELDS(pa_bluetooth_uuid);
};
-/* This enum is shared among Audio, Headset, and AudioSink, although not all values are acceptable in all profiles */
+/* This enum is shared among Audio, Headset, AudioSink, and AudioSource, although not all values are acceptable in all profiles */
typedef enum pa_bt_audio_state {
PA_BT_AUDIO_STATE_INVALID = -1,